/****************************************************************************
** ViewerView meta object code from reading C++ file 'viewer-qt.h'
**
** Created: Wed May 2 10:50:42 2001
**      by: The Qt MOC ($Id: qt/src/moc/moc.y   2.3.0   edited 2001-02-20 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 9
#elif Q_MOC_OUTPUT_REVISION != 9
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "viewer-qt.h"
#include <qmetaobject.h>
#include <qapplication.h>



const char *ViewerView::className() const
{
    return "ViewerView";
}

QMetaObject *ViewerView::metaObj = 0;

void ViewerView::initMetaObject()
{
    if ( metaObj )
	return;
    if ( qstrcmp(QScrollView::className(), "QScrollView") != 0 )
	badSuperclassWarning("ViewerView","QScrollView");
    (void) staticMetaObject();
}

#ifndef QT_NO_TRANSLATION

QString ViewerView::tr(const char* s)
{
    return qApp->translate( "ViewerView", s, 0 );
}

QString ViewerView::tr(const char* s, const char * c)
{
    return qApp->translate( "ViewerView", s, c );
}

#endif // QT_NO_TRANSLATION

QMetaObject* ViewerView::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    (void) QScrollView::staticMetaObject();
#ifndef QT_NO_PROPERTIES
#endif // QT_NO_PROPERTIES
    QMetaData::Access *slot_tbl_access = 0;
    metaObj = QMetaObject::new_metaobject(
	"ViewerView", "QScrollView",
	0, 0,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    metaObj->set_slot_access( slot_tbl_access );
#ifndef QT_NO_PROPERTIES
#endif // QT_NO_PROPERTIES
    return metaObj;
}


const char *ViewerWindow::className() const
{
    return "ViewerWindow";
}

QMetaObject *ViewerWindow::metaObj = 0;

void ViewerWindow::initMetaObject()
{
    if ( metaObj )
	return;
    if ( qstrcmp(QMainWindow::className(), "QMainWindow") != 0 )
	badSuperclassWarning("ViewerWindow","QMainWindow");
    (void) staticMetaObject();
}

#ifndef QT_NO_TRANSLATION

QString ViewerWindow::tr(const char* s)
{
    return qApp->translate( "ViewerWindow", s, 0 );
}

QString ViewerWindow::tr(const char* s, const char * c)
{
    return qApp->translate( "ViewerWindow", s, c );
}

#endif // QT_NO_TRANSLATION

QMetaObject* ViewerWindow::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    (void) QMainWindow::staticMetaObject();
#ifndef QT_NO_PROPERTIES
#endif // QT_NO_PROPERTIES
    typedef void (ViewerWindow::*m1_t0)(int);
    typedef void (QObject::*om1_t0)(int);
    typedef void (ViewerWindow::*m1_t1)();
    typedef void (QObject::*om1_t1)();
    typedef void (ViewerWindow::*m1_t2)();
    typedef void (QObject::*om1_t2)();
    m1_t0 v1_0 = &ViewerWindow::fillStyleCombo;
    om1_t0 ov1_0 = (om1_t0)v1_0;
    m1_t1 v1_1 = &ViewerWindow::fontChanged;
    om1_t1 ov1_1 = (om1_t1)v1_1;
    m1_t2 v1_2 = &ViewerWindow::setRightToLeft;
    om1_t2 ov1_2 = (om1_t2)v1_2;
    QMetaData *slot_tbl = QMetaObject::new_metadata(3);
    QMetaData::Access *slot_tbl_access = QMetaObject::new_metaaccess(3);
    slot_tbl[0].name = "fillStyleCombo(int)";
    slot_tbl[0].ptr = (QMember)ov1_0;
    slot_tbl_access[0] = QMetaData::Private;
    slot_tbl[1].name = "fontChanged()";
    slot_tbl[1].ptr = (QMember)ov1_1;
    slot_tbl_access[1] = QMetaData::Private;
    slot_tbl[2].name = "setRightToLeft()";
    slot_tbl[2].ptr = (QMember)ov1_2;
    slot_tbl_access[2] = QMetaData::Private;
    metaObj = QMetaObject::new_metaobject(
	"ViewerWindow", "QMainWindow",
	slot_tbl, 3,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    metaObj->set_slot_access( slot_tbl_access );
#ifndef QT_NO_PROPERTIES
#endif // QT_NO_PROPERTIES
    return metaObj;
}
